@@ -1,19 +1,19 @@
 // -*- c++ -*-
-/* $Id: value.cc 779 2009-01-19 17:58:50Z murrayc $ */
+/* $Id: value.cc 231 2005-11-29 15:04:05Z  $ */
 
 /* Copyright 2002 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU Library General Public
  * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -39,14 +39,6 @@ void ValueBase::init(GType type)
   g_value_init(&gobject_, type);
 }
 
-void ValueBase::init(const GValue* value)
-{
-  g_value_init(&gobject_, G_VALUE_TYPE(value));
-
-  if(value)
-    g_value_copy(value, &gobject_);
-}
-
 ValueBase::ValueBase(const ValueBase& other)
 {
   GLIBMM_INITIALIZE_STRUCT(gobject_, GValue);
